pytket.phir package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pytket.phir.rebasing
   pytket.phir.sharding

Submodules
----------

pytket.phir.api module
----------------------

.. automodule:: pytket.phir.api
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.cli module
----------------------

.. automodule:: pytket.phir.cli
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.machine module
--------------------------

.. automodule:: pytket.phir.machine
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.phirgen module
--------------------------

.. automodule:: pytket.phir.phirgen
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.phirgen\_parallel module
------------------------------------

.. automodule:: pytket.phir.phirgen_parallel
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.place\_and\_route module
------------------------------------

.. automodule:: pytket.phir.place_and_route
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.placement module
----------------------------

.. automodule:: pytket.phir.placement
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.qtm\_machine module
-------------------------------

.. automodule:: pytket.phir.qtm_machine
   :members:
   :undoc-members:
   :show-inheritance:

pytket.phir.routing module
--------------------------

.. automodule:: pytket.phir.routing
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pytket.phir
   :members:
   :undoc-members:
   :show-inheritance:
